from ..ncommon.nout import *
from .dstatus import *
import pymysql
from dataclasses import dataclass

@dataclass
class n_mysql:
    host = ...
    port = ...
    user = ...
    password = ...
    charset = ...
    connection: pymysql.connections.Connection | None = ...
    def __init__(self, host: str | None = None, port: int | None = None, user: str | None = None, password: str | None = None, charset: str = 'utf8') -> None: ...
    @classmethod
    def getInstance(cls, connect: pymysql.connections.Connection | None = None, *, host: str = None, port: int = None, user: str = None, password: str = None, charset: str = 'utf8') -> n_mysql | None: ...
    def connect_mysql_server(self, commit_status: Commit_Status = ...): ...
    def setup(self, db_name: str, is_start_transaction: bool = False) -> None: ...
    def connect_database(self, db_name: str) -> None: ...
    def disconnect_mysql_server(self) -> None: ...
    def excuse_command(self, cmd: str) -> None: ...
    @property
    def Commit_status(self) -> Commit_Status: ...
    def data_to_list(self, data: str) -> list[str]: ...
    def data_to_list2(self, data: str) -> list[str]: ...
    def set_Commit_Status(self, Commit_status) -> None: ...
    def startTransAction(self) -> None: ...
    def Commit(self) -> None: ...
    def rollback(self) -> None: ...
    def execute_sql_language(self, sql_language: str) -> tuple[tuple[any, ...], ...]: ...
    @property
    def connect_status(self) -> Sql_Status: ...
    def is_database_exists(self, database_name: str) -> bool: ...
    def create_database(self, database_name: str) -> None: ...
    def is_has_Table(self, tb_name: str) -> bool: ...
    def showTables(self) -> list[str]: ...
    def is_has_View(self, view_name: str) -> bool: ...
    def __del__(self) -> None: ...



from ctypes import *
from _typeshed import Incomplete

__all__ = ['test_lib']

class external_libs:
    class _test_lib:
        def __init__(self) -> None: ...
        def func1(self, string: str): ...
        def func2(self, a: int, b: int) -> int: ...
        def func3(self) -> float: ...

test_lib: Incomplete



import enum
from _typeshed import Incomplete

class NtsuQueryError(Exception):
    msg: Incomplete
    line_number: Incomplete
    def __init__(self, msg) -> None: ...

class query_type(enum.Enum):
    SteamAPI = 0
    A2S = 1

class n_valveServerQuery:
    class server_info:
        server_ip: Incomplete
        server_port: Incomplete
        server_name: Incomplete
        server_transname: Incomplete
        server_onlineplayer_count: Incomplete
        server_maxplayer_count: Incomplete
        server_mapname: Incomplete
        game: Incomplete
        timeout: Incomplete
        gametype: Incomplete
        querystatus: Incomplete
        def __init__(self, server_ip: str, server_port: int, server_name: str = None, server_onlineplayer_count: int = None, server_maxplayer_count: int = None, server_mapname: str = None, game: str = None, timeout: int = None, gametype: Incomplete | None = None, querystatus: bool = False) -> None: ...
        def is_error(self): ...
    timeout: Incomplete
    retrytimes: Incomplete
    encoding: Incomplete
    header: Incomplete
    session: Incomplete
    steamwebapikey: Incomplete
    def __init__(self, timeout: float, encoding: str, steamwebapikey: str, retrytimes: int = 0) -> None: ...
    @classmethod
    def resolve_domain_to_ip(cls, domain): ...
    def query_servers(self, addresses: list, q_type: query_type, max_workers: int = 5, group: int = 2, interval: float = 0.1) -> list[server_info]: ...



import psycopg2
from .dstatus import Commit_Status, Isolation_Status, Sql_Status
from _typeshed import Incomplete
from typing import Any

__all__ = ['n_postgresql']

class n_postgresql:
    debug: bool
    @classmethod
    def set_pool_debug(cls, debug: bool) -> None: ...
    def set_connect_debug(self, debug: bool) -> None: ...
    @classmethod
    def initialize_pool(cls, minconn: int = 1, maxconn: int = 10, **kwargs): ...
    @classmethod
    def start_healthcheckthread(cls, interval: float = 15.0): ...
    @classmethod
    def stop_healthcheckthread(cls) -> None: ...
    @classmethod
    def close_pool(cls) -> None: ...
    host: Incomplete
    port: Incomplete
    user: Incomplete
    password: Incomplete
    charset: Incomplete
    connection: psycopg2.extensions.connection | None
    use_pool: Incomplete
    def __init__(self, host: str | None = None, port: int | None = None, user: str | None = None, password: str | None = None, charset: str = 'utf8', debug: bool = False, use_pool: bool = False) -> None: ...
    @classmethod
    def getInstance(cls, connect: psycopg2.extensions.connection | None = None, *, host: str = None, port: int = None, user: str = None, password: str = None, charset: str = 'utf8', debug: bool = False) -> n_postgresql | None: ...
    def connect_server(self, commit_status: Commit_Status = ...): ...
    def setup(self, db_name: str, is_start_transaction: bool = False) -> None: ...
    def use_database(self, db_name: str) -> None: ...
    def exec_cmd(self, cmd: str) -> str | list[tuple[Any, ...]] | None: ...
    def exec_language(self, sql_language: str, params: Incomplete | None = None, fetch: Incomplete | None = None) -> tuple[tuple[Any, ...], ...] | None: ...
    @property
    def isolation(self) -> Isolation_Status | None: ...
    @isolation.setter
    def isolation(self, iso_status: Isolation_Status): ...
    def quick_select(self, name: str, limit: int | None = None) -> list | None: ...
    @property
    def commit_status(self) -> Commit_Status: ...
    @commit_status.setter
    def commit_status(self, status: Commit_Status): ...
    @property
    def current_db(self) -> str | None: ...
    @current_db.setter
    def current_db(self, db_name: str): ...
    def startTransAction(self) -> None: ...
    def commit(self) -> None: ...
    def rollback(self) -> None: ...
    @property
    def connect_status(self) -> Sql_Status: ...
    def exists_db(self, database_name: str) -> bool: ...
    def create_database(self, database_name: str) -> None: ...
    def exists_table(self, tb_name: str, schema: str = 'public') -> bool: ...
    def showDatabases(self) -> list[str]: ...
    def showViews(self) -> list[str]: ...
    def showTables(self) -> list[str]: ...
    def exists_view(self, view_name: str, schema: str = 'public') -> bool: ...
    def drop_table(self, tb_name: str): ...
    def drop_database(self, db_name: str) -> None: ...
    def drop_view(self, view_name: str): ...
    def getEncryAccountPassword(self, username: str) -> str: ...
    def resetPassword(self, new_password: str, username: str | None = None, require_old_password: bool = False, old_password: str | None = None): ...
    def createAdminAccount(self, username: str, password: str) -> bool: ...
    def createOnlyReadAccount(self, username: str, password: str) -> bool: ...
    def createDefaultAccount(self, username: str, password: str) -> bool: ...
    def deleteAccountAnyWay(self, account_name: str) -> bool: ...
    def showAllAccountWithPermission(self) -> list: ...
    @staticmethod
    def print_as_table(data: list, headers: Incomplete | None = None): ...
    def disconnect_server(self) -> None: ...
    def __enter__(self): ...
    def __exit__(self, exc_type: type[BaseException] | None, exc_val: BaseException | None, exc_tb: types.TracebackType | None) -> None: ...
    def __del__(self) -> None: ...



__all__ = ['InputValidator']

class InputValidator:
    @staticmethod
    def getEmailRegular(): ...
    @staticmethod
    def getUsernameRegular(): ...
    @staticmethod
    def getPasswordRegular(): ...
    @staticmethod
    def getPhoneRegular(): ...
    @staticmethod
    def validate(input_str, pattern): ...
